# Samples

Here are samples to test cx_Freeze or to show how to use a package in cx_Freeze.

# Source

https://docs.scipy.org/doc/scipy/tutorial/stats.html

# Installation and requirements:

In a virtual environment, install by issuing the command:

```
pip install --upgrade cx_Freeze scipy
```
